%global commit 4f9c1130e1fd46a66729039f1f18ea7c29c6eac0
%global shortcommit %(c=%{commit}; echo ${c:0:7})
%global ver_major 0
%global ver_minor 16
%global ver_patch 1
%define ocever %{ver_major}.%{ver_minor}.%{ver_patch}
%define occver 6.7.1
%define sname OCE

%define libmajor 0
%define libname %mklibname %{name} %{libmajor}
%define devname %mklibname -d %{name}


Name:           opencascade
Version:        %{occver}
Release:        %mkrel 1
Summary:        OpenCASCADE Community Edition
Group:		Sciences/Physics
License:        LGPLv2 with exception
URL:            https://github.com/tpaviot/oce
Source0:        https://github.com/tpaviot/oce/archive/%{commit}/oce-%{sname}-%{ocever}.tar.xz
Source1:        DRAWEXE.1
Source2:        opencascade-draw.desktop
Source3:        oce-256.png
Source4:        oce-128.png
Source5:        oce-64.png
Source6:        oce-48.png

# Utilities
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
# Libraries
BuildRequires:  x11-proto-devel
BuildRequires:  mesagl-devel mesaglu-devel
BuildRequires:  libxmu-devel
BuildRequires:  ftgl-devel
BuildRequires:  freeimage-devel
BuildRequires:  gl2ps-devel
BuildRequires:  libgomp-devel
BuildRequires:  tcl-devel
BuildRequires:  tk-devel
BuildRequires:  tbb-devel
Provides:       bundled(gnulib)
Provides:       OCE
Provides:       opencascade-OCE
Conflicts:	%{_lib}opencascade0 < %{occver}

%description
OpenCASCADE Community Edition (OCE) is a suite for 3D surface and solid
modeling, visualization, data exchange and rapid application development. It
is an excellent platform for development of numerical simulation software
including CAD/CAM/CAE, AEC and GIS, as well as PDM applications.

#-----------------------------------------------------------------------
%package -n %{libname}
Summary:	3D modeling & numerical simulation
Group:		System/Libraries

%description	-n %{libname}
Open CASCADE Technology is software development platform freely available
in open source. It includes components for 3D surface and solid modeling,
visualization, data exchange and rapid application development.

Open CASCADE Technology can be best applied in development of numerical
simulation software including CAD/CAM/CAE, AEC and GIS, as well as PDM
applications.

The Technology exists from the mid 1990-s and has already been used by
numerous commercial clients belonging to different domains from software
edition to heavy industry.


%package -n %{devname}
Summary:        OpenCASCADE CAE platform library development files
Group:          Development/Libraries
Provides:	OCE-devel
Provides:	opencascade-OCE-devel
Provides:	opencascade-devel
Requires:	%{libname} = %{version}
Provides:	%{name}-devel = %{version}

%description -n %{devname}
OpenCASCADE CAE platform library development files


%prep
%setup -q -n oce-%{sname}-%{ocever}


%build
rm -fr %{buildroot}
# Stop excessive linking that cmake projects are prone to. 
export LDFLAGS="-Wl,--as-needed"
%cmake -DCMAKE_BUILD_TYPE=RelWithDebInfo \
       -DOCE_INSTALL_PREFIX=%{_prefix} \
       -DOCE_INSTALL_LIB_DIR=%{_lib} \
       -DOCE_WITH_FREEIMAGE=ON \
       -DOCE_WITH_GL2PS=ON \
%ifnarch ppc64
       -DOCE_MULTITHREAD_LIBRARY:STRING=TBB \
%else
       -DOCE_MULTITHREAD_LIBRARY:STRING=OPENMP \
%endif
       -DOCE_DRAW=ON \
       -DOCE_TESTING=ON \
       ..

%make

%install
rm -rf %buildroot
pushd build
%make_install
popd

# Install manpage for DRAWEXE
install -Dm 0644 %{SOURCE1} %{buildroot}%{_mandir}/man1/DRAWEXE.1

# Install and validate desktop file
desktop-file-install                           \
    --dir=%{buildroot}%{_datadir}/applications \
    %{SOURCE2}

# Install icons
for size in 256 128 64 48; do
    icon=%{_sourcedir}/oce-${size}.png
    install -Dm 0644 $icon \
        %{buildroot}%{_datadir}/icons/hicolor/${size}x${size}/apps/oce.png
done


%clean
rm -rf %{buildroot}

%files
#%%files foundation
%doc AUTHORS LICENSE_LGPL_21.txt NEWS OCCT_LGPL_EXCEPTION.txt
%{_datadir}/oce-%{ver_major}.%{ver_minor}/
%{_bindir}/DRAWEXE
%{_mandir}/man1/DRAWEXE.1.bz2
%{_datadir}/applications/opencascade-draw.desktop
%{_datadir}/icons/hicolor/*/apps/*

%files -n %{libname}
# Foundation
%{_libdir}/libTKernel.so.*
%{_libdir}/libTKMath.so.*
%{_libdir}/libTKAdvTools.so.*
#%%files modeling
# Modeling Data
%{_libdir}/libTKG2d.so.*
%{_libdir}/libTKG3d.so.*
%{_libdir}/libTKGeomBase.so.*
%{_libdir}/libTKBRep.so.*
# Modeling Algorithms
%{_libdir}/libTKGeomAlgo.so.*
%{_libdir}/libTKTopAlgo.so.*
%{_libdir}/libTKPrim.so.*
%{_libdir}/libTKBO.so.*
%{_libdir}/libTKHLR.so.*
%{_libdir}/libTKMesh.so.*
%{_libdir}/libTKShHealing.so.*
%{_libdir}/libTKXMesh.so.*
%{_libdir}/libTKBool.so.*
%{_libdir}/libTKFillet.so.*
%{_libdir}/libTKFeat.so.*
%{_libdir}/libTKOffset.so.*
# Data exchange
%{_libdir}/libTKSTL.so.*
%{_libdir}/libTKXSBase.so.*
%{_libdir}/libTKSTEPBase.so.*
%{_libdir}/libTKIGES.so.*
%{_libdir}/libTKSTEPAttr.so.*
%{_libdir}/libTKSTEP209.so.*
%{_libdir}/libTKSTEP.so.*
%{_libdir}/libTKVRML.so.*
%{_libdir}/libTKXCAF.so.*
%{_libdir}/libTKXCAFSchema.so.*
%{_libdir}/libTKXmlXCAF.so.*
%{_libdir}/libTKBinXCAF.so.*
%{_libdir}/libTKXDEIGES.so.*
%{_libdir}/libTKXDESTEP.so.*

#%%files visualization
# Visualization Dependents
%{_libdir}/libTKService.so.*
%{_libdir}/libTKV3d.so.*
# Visualization
%{_libdir}/libTKOpenGl.so.*
%{_libdir}/libTKMeshVS.so.*
%{_libdir}/libTKNIS.so.*
%{_libdir}/libTKVoxel.so.*

#%%files ocaf
# Application framework
%{_libdir}/libTKCDF.so.*
%{_libdir}/libPTKernel.so.*
%{_libdir}/libTKLCAF.so.*
%{_libdir}/libFWOSPlugin.so.*
%{_libdir}/libTKPShape.so.*
%{_libdir}/libTKBinL.so.*
%{_libdir}/libTKXmlL.so.*
%{_libdir}/libTKPLCAF.so.*
%{_libdir}/libTKTObj.so.*
%{_libdir}/libTKShapeSchema.so.*
%{_libdir}/libTKStdLSchema.so.*
%{_libdir}/libTKCAF.so.*
%{_libdir}/libTKBin.so.*
%{_libdir}/libTKXml.so.*
%{_libdir}/libTKPCAF.so.*
%{_libdir}/libTKBinTObj.so.*
%{_libdir}/libTKXmlTObj.so.*
%{_libdir}/libTKStdSchema.so.*

#%%files draw
# Draw Libraries
%dir %{_libdir}/oce-%{ver_major}.%{ver_minor}
%{_libdir}/oce-%{ver_major}.%{ver_minor}/libTKDraw.so.*
%{_libdir}/oce-%{ver_major}.%{ver_minor}/libTKTopTest.so.*
%{_libdir}/oce-%{ver_major}.%{ver_minor}/libTKViewerTest.so.*
%{_libdir}/oce-%{ver_major}.%{ver_minor}/libTKXSDRAW.so.*
%{_libdir}/oce-%{ver_major}.%{ver_minor}/libTKDCAF.so.*
%{_libdir}/oce-%{ver_major}.%{ver_minor}/libTKXDEDRAW.so.*
%{_libdir}/oce-%{ver_major}.%{ver_minor}/libTKTObjDRAW.so.*


%files -n %{devname}
%doc examples
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/oce-%{ver_major}.%{ver_minor}/*.so
%{_libdir}/oce-%{ver_major}.%{ver_minor}/*.cmake



%changelog
* Fri Aug 07 2015 bb <bb> 6.7.1-1pclos2015
- packaged wrong since it was already packaged in 2012 properly

* Sun Jun 07 2015 gseaman <galen.seaman at comcast.net> 0.16.1-1gseaman2015
- build for PCLinuxOS from Fedora spec
